@@ -1,8 +1,10 @@
 from .simulationwithredux2 import Simulator
+from .simulationwithredux2 import simpleODESolver
+from .simulationwithredux2 import createDataSelector
 
 import scipy.integrate as integrate
 
-def createDataSelector(masterMaps, maps):
+def CreateDataSelector(masterMaps, maps):
     def extractor(dataItem):
         result = {}
         for masterName, masterFunc in masterMaps.items():
@@ -12,7 +14,7 @@ def createDataSelector(masterMaps, maps):
         return result
     return extractor
 
-def simpleODESolver(model, t0, state0, t_bound, max_step):
+def SimpleODESolver(model, t0, state0, t_bound, max_step):
     if not callable(model):
         raise ValueError('Model must be callable')
 
